@@ -200,10 +200,13 @@ container           = "andrewzhu"
 abr = AzureBlobReader(blob_conn_str=connect_str,container_name=container)
 
 #%% blob upload test
+import time
 blob_file_path      = r'powerapps_data/pa_daily_temp.csv'
 local_csv_path      = r'data/scope_query_temp.csv'
+s = time.time()
 abr.upload_file_chunks(blob_file_path=blob_file_path,local_file_path=local_csv_path)
-print('done')
+print('done, use time',(time.time() -s))
+
 
 #%% download test
 blob_file_path = 'temp_query_data.csv'
